diff --git a/src/assets/styles/common.less b/src/assets/styles/common.less
index 8ed396d6..0df097cd 100644
--- a/src/assets/styles/common.less
+++ b/src/assets/styles/common.less
@@ -344,3 +344,16 @@ textarea:hover {
.text-success {
color: var(--ant-color-success);
}
+
+.desc-fill {
+ font-weight: 600;
+ color: var(--ant-color-text);
+ background-color: var(--ant-color-fill-content);
+ line-height: 1.5;
+ padding: 2px 6px;
+ border-radius: 4px;
+}
+
+.line-6 {
+ line-height: 24px;
+}
diff --git a/src/locales/en-US/clusters.ts b/src/locales/en-US/clusters.ts
index dbf92c84..31656304 100644
--- a/src/locales/en-US/clusters.ts
+++ b/src/locales/en-US/clusters.ts
@@ -51,8 +51,7 @@ export default {
'If multiple outbound IPs exist, specify the one you want the worker to use. Please double-check with hostname -I | xargs -n1.',
'clusters.addworker.nvidiaNotes-02':
'If a model directory already exists on the worker, you can specify the path to mount it.',
- 'clusters.addworker.hygonNotes': `If the /opt/hyhal directory does not exist, create a symbolic link to the Hygon installation path.
-Same applies to the /opt/dtk directory.`,
+ 'clusters.addworker.hygonNotes': `If /opt/hyhal or /opt/dtk does not exist, create symbolic links pointing to the corresponding Hygon installation paths, for example: ln -s /path/to/hyhal /opt/hyhal ln -s /path/to/dtk /opt/dtk.`,
'clusters.addworker.corexNotes': `If the /lib/modules directory does not exist, create a symbolic link to the Iluvatar installation path:
ln -s /path/to/corex /lib/modules. Same applies to the /usr/local/corex directory.`,
'clusters.addworker.metaxNotes': `If the /opt/mxdriver directory does not exist, create a symbolic link to the MetaX installation path:
diff --git a/src/locales/ru-RU/clusters.ts b/src/locales/ru-RU/clusters.ts
index 62f9c807..9c053c70 100644
--- a/src/locales/ru-RU/clusters.ts
+++ b/src/locales/ru-RU/clusters.ts
@@ -51,8 +51,7 @@ export default {
'Если существует несколько исходящих IP-адресов, укажите тот, который должен использовать воркер. Пожалуйста, перепроверьте с помощью hostname -I | xargs -n1.',
'clusters.addworker.nvidiaNotes-02':
'Если директория с моделями уже существует на воркере, вы можете указать путь для её монтирования.',
- 'clusters.addworker.hygonNotes':
- 'Если директория /opt/hyhal не существует, создайте символическую ссылку на путь установки Hygon: /opt/hyhal. Аналогично для директории /opt/dtk.',
+ 'clusters.addworker.hygonNotes': `If /opt/hyhal or /opt/dtk does not exist, create symbolic links pointing to the corresponding Hygon installation paths, for example: ln -s /path/to/hyhal /opt/hyhal ln -s /path/to/dtk /opt/dtk.`,
'clusters.addworker.corexNotes':
'Если директория /lib/modules не существует, создайте символическую ссылку на путь установки Iluvatar: ln -s /path/to/corex /lib/modules. Аналогично для директории /usr/local/corex.',
'clusters.addworker.metaxNotes':
@@ -100,9 +99,9 @@ export default {
'Нужен новый токен? Нажмите здесь.',
'clusters.addworker.amdNotes-01': `Если директория /opt/rocm не существует, создайте символическую ссылку на путь установки ROCm: ln -s /путь/к/rocm /opt/rocm.`,
'clusters.addworker.message.success_single':
- '{count} новый воркер был добавлен в кластер.',
+ '{count} новый воркер был добавлен в кластер.',
'clusters.addworker.message.success_multiple':
- '{count} новых воркеров были добавлены в кластер.',
+ '{count} новых воркеров были добавлены в кластер.',
'clusters.create.serverUrl': 'URL сервера',
'clusters.create.workerConfig': 'Конфигурация воркера',
'clusters.addworker.containerName': 'Имя контейнера воркера',
@@ -114,11 +113,12 @@ export default {
'clusters.table.ip.internal': 'Внутренний',
'clusters.table.ip.external': 'Внешний',
'clusters.form.serverUrl.tips':
- 'Укажите URL сервера, доступный из вашего облачного провайдера.',
+ 'Укажите URL сервера, доступный из вашего облачного провайдера.',
'clusters.form.setDefault': 'Установить по умолчанию',
- 'clusters.form.setDefault.tips': 'Использовать по умолчанию для развертывания.',
+ 'clusters.form.setDefault.tips':
+ 'Использовать по умолчанию для развертывания.'
};
// ========== To-Do: Translate Keys (Remove After Translation) ==========
-
+// 1. 'clusters.addworker.hygonNotes': `If /opt/hyhal or /opt/dtk does not exist, create symbolic links pointing to the corresponding Hygon installation paths, for example: ln -s /path/to/hyhal /opt/hyhal ln -s /path/to/dtk /opt/dtk.`,
// ================================================================
diff --git a/src/locales/zh-CN/clusters.ts b/src/locales/zh-CN/clusters.ts
index 146bafe1..17c778dc 100644
--- a/src/locales/zh-CN/clusters.ts
+++ b/src/locales/zh-CN/clusters.ts
@@ -49,8 +49,9 @@ export default {
'如果节点有多个出站 IP 地址,请填写 WORKER_IP,以确保使用指定的 IP。可通过命令 hostname -I | xargs -n1 进行确认。',
'clusters.addworker.nvidiaNotes-02':
'如果节点上已经存在模型目录,你可以指定该路径进行挂载。',
- 'clusters.addworker.hygonNotes':
- '如果 /opt/hyhal 目录不存在,请创建指向海光安装路径的符号链接:/opt/hyhal。与 /opt/dtk 目录相同。',
+ 'clusters.addworker.hygonNotes': `如果 /opt/hyhal 或 /opt/dtk 不存在,请创建指向对应海光安装路径的符号链接,例如:
+ ln -s /path/to/hyhal /opt/hyhal
+ ln -s /path/to/dtk /opt/dtk`,
'clusters.addworker.corexNotes':
'如果 /lib/modules 目录不存在,请创建指向天数智芯安装路径的符号链接:ln -s /path/to/corex /lib/modules。与 /usr/local/corex 目录相同。',
'clusters.addworker.metaxNotes':
diff --git a/src/locales/ja-JP/clusters.ts b/src/locales/ja-JP/clusters.ts
index afde3a11..403fbc10 100644
--- a/src/locales/ja-JP/clusters.ts
+++ b/src/locales/ja-JP/clusters.ts
@@ -51,8 +51,7 @@ export default {
'If multiple outbound IPs exist, specify the one you want the worker to use. Please double-check with hostname -I | xargs -n1.',
'clusters.addworker.nvidiaNotes-02':
'If a model directory already exists on the worker, you can specify the path to mount it.',
- 'clusters.addworker.hygonNotes': `If the /opt/hyhal directory does not exist, create a symbolic link to the Hygon installation path.
-Same applies to the /opt/dtk directory.`,
+ 'clusters.addworker.hygonNotes': `If /opt/hyhal or /opt/dtk does not exist, create symbolic links pointing to the corresponding Hygon installation paths, for example: ln -s /path/to/hyhal /opt/hyhal ln -s /path/to/dtk /opt/dtk.`,
'clusters.addworker.corexNotes': `If the /lib/modules directory does not exist, create a symbolic link to the Iluvatar installation path:
ln -s /path/to/corex /lib/modules. Same applies to the /usr/local/corex directory.`,
'clusters.addworker.metaxNotes': `If the /opt/mxdriver directory does not exist, create a symbolic link to the MetaX installation path:
@@ -165,7 +164,7 @@ Same applies to the /opt/dtk directory.`,
// 43. 'cluster.provider.comingsoon': 'Coming soon',
// 44. 'clusters.addworker.nvidiaNotes-01': 'If multiple outbound IPs exist, specify the one you want the worker to use. Please double-check with hostname -I | xargs -n1.',
// 45. 'clusters.addworker.nvidiaNotes-02': 'If a model directory already exists on the worker, you can specify the path to mount it.',
// 46. 'clusters.addworker.hygonNotes': 'If the /opt/hyhal directory does not exist, create a symbolic link to the Hygon installation path. Same applies to the /opt/dtk directory.',
// 47. 'clusters.addworker.corexNotes': 'If the /lib/modules directory does not exist, create a symbolic link to the Iluvatar installation path: ln -s /path/to/corex /lib/modules. Same applies to the /usr/local/corex directory.',
// 48. 'clusters.addworker.metaxNotes': 'If the /opt/mxdriver directory does not exist, create a symbolic link to the MetaX installation path: ln -s /path/to/metax /opt/mxdriver. Same applies to the /opt/maca directory.',
// 49. 'clusters.addworker.cambriconNotes': 'If the /usr/local/neuware directory does not exist, create a symbolic link to the Cambricon installation path: ln -s /path/to/neuware /usr/local/neuware.'
@@ -165,7 +164,7 @@ Same applies to the /opt/dtk directory.`,
// 44. 'clusters.addworker.nvidiaNotes-01': 'If multiple outbound IPs exist, specify the one you want the worker to use. Please double-check with hostname -I | xargs -n1.',
// 45. 'clusters.addworker.nvidiaNotes-02': 'If a model directory already exists on the worker, you can specify the path to mount it.',
-// 46. 'clusters.addworker.hygonNotes': 'If the /opt/hyhal directory does not exist, create a symbolic link to the Hygon installation path. Same applies to the /opt/dtk directory.',
+// 46. 'clusters.addworker.hygonNotes': `If /opt/hyhal or /opt/dtk does not exist, create symbolic links pointing to the corresponding Hygon installation paths, for example: ln -s /path/to/hyhal /opt/hyhal ln -s /path/to/dtk /opt/dtk.`,
// 47. 'clusters.addworker.corexNotes': 'If the /lib/modules directory does not exist, create a symbolic link to the Iluvatar installation path: ln -s /path/to/corex /lib/modules. Same applies to the /usr/local/corex directory.',
// 48. 'clusters.addworker.metaxNotes': 'If the /opt/mxdriver directory does not exist, create a symbolic link to the MetaX installation path: ln -s /path/to/metax /opt/mxdriver. Same applies to the /opt/maca directory.',